Structs
- Binary
Pin - Lockfile pin for a
hub:node resolved to a prebuilt binary artifact (spec 8.2). MirrorsGitSourcefor the binary source form: theurl+sha256pin the bytes (re-verified on download), andhubrecords the package/version/manifest provenance for--lockedtamper detection. - Daemon
Id - GitSource
- HubProvenance
- Identity of the hub package a git source was resolved from.
- LogMessage
- LogMessage
Helper - Node
Error - Timestamped
Enums
- Data
Message - LogLevel
- An enum representing the available verbosity levels of the logger.
- LogLevel
OrStdout - Node
Error Cause - Node
Exit Status