pub struct Input {
pub mapping: InputMapping,
pub queue_size: Option<usize>,
pub input_timeout: Option<f64>,
pub queue_policy: Option<QueuePolicy>,
}Fields
mapping: InputMappingqueue_size: Option<usize>input_timeout: Option<f64>queue_policy: Option<QueuePolicy>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Input
impl<'de> Deserialize<'de> for Input
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for Input
Sourceimpl JsonSchema for Input
impl JsonSchema for Input
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for Input
impl RefUnwindSafe for Input
impl Send for Input
impl Sync for Input
impl Unpin for Input
impl UnsafeUnpin for Input
impl UnwindSafe for Input