pub struct NodeRunConfig {
pub inputs: BTreeMap<DataId, Input>,
pub outputs: BTreeSet<DataId>,
pub output_types: BTreeMap<DataId, String>,
pub output_framing: BTreeMap<DataId, OutputFraming>,
pub input_types: BTreeMap<DataId, String>,
pub shared_memory_pool_size: Option<ByteSize>,
}Expand description
Contains the input and output configuration of the node.
Fields
inputs: BTreeMap<DataId, Input>Inputs for the nodes as a map from input ID to node_id/output_id.
e.g.
inputs:
example_input: example_node/example_output1
outputs: BTreeSet<DataId>List of output IDs.
e.g.
outputs:
-
output_1
-
output_2
output_types: BTreeMap<DataId, String>Optional type annotations for outputs
output_framing: BTreeMap<DataId, OutputFraming>Per-output framing overrides (default: Raw for all).
input_types: BTreeMap<DataId, String>Optional type annotations for inputs
Size of the zenoh shared memory pool for zero-copy output publishing.
Accepts an integer (raw bytes) or a string with a unit suffix
(KB, MB, GB, case-insensitive).
e.g.
shared_memory_pool_size: 128MB