pub struct SpawnDataflowNodes {
pub build_id: Option<BuildId>,
pub session_id: SessionId,
pub dataflow_id: DataflowId,
pub local_working_dir: Option<PathBuf>,
pub nodes: BTreeMap<NodeId, ResolvedNode>,
pub dataflow_descriptor: Descriptor,
pub spawn_nodes: BTreeSet<NodeId>,
pub uv: bool,
pub write_events_to: Option<PathBuf>,
pub artifact_base_url: Option<String>,
}Fields
build_id: Option<BuildId>session_id: SessionIddataflow_id: DataflowIdlocal_working_dir: Option<PathBuf>Allows overwriting the base working dir when CLI and daemon are running on the same machine.
Must not be used for multi-machine dataflows.
Note that nodes with git sources still use a subdirectory of the base working dir.
nodes: BTreeMap<NodeId, ResolvedNode>dataflow_descriptor: Descriptorspawn_nodes: BTreeSet<NodeId>uv: boolwrite_events_to: Option<PathBuf>artifact_base_url: Option<String>Base URL for downloading artifacts from the coordinator (HTTP distribution mode).
When set, daemons can pull binaries from {artifact_base_url}/{build_id}/{node_id}.