Module daemon_to_node

Module daemon_to_node 

Re-exports

pub use crate::common::DataMessage;
pub use crate::common::SharedMemoryId;
pub use crate::common::Timestamped;

Structs

NodeConfig
OutputRouting
Data-plane routing for one node output — see NodeConfig::output_routing.
RequiredAcker
Identity of one consumer input that must ack a producer’s startup markers before the producer may switch the corresponding output to the direct zenoh path — see OutputRouting::required_ackers.
RuntimeConfig

Enums

DaemonCommunication
DaemonReply
NodeEvent