pub struct RequiredAcker {
pub node_id: NodeId,
pub input_id: DataId,
}Expand description
Identity of one consumer input that must ack a producer’s startup markers
before the producer may switch the corresponding output to the direct zenoh
path — see OutputRouting::required_ackers.
Fields
node_id: NodeIdinput_id: DataIdTrait Implementations
Sourceimpl Clone for RequiredAcker
impl Clone for RequiredAcker
Sourcefn clone(&self) -> RequiredAcker
fn clone(&self) -> RequiredAcker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RequiredAcker
impl Debug for RequiredAcker
Sourceimpl<'de> Deserialize<'de> for RequiredAcker
impl<'de> Deserialize<'de> for RequiredAcker
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RequiredAcker
Sourceimpl Ord for RequiredAcker
impl Ord for RequiredAcker
Sourcefn cmp(&self, other: &RequiredAcker) -> Ordering
fn cmp(&self, other: &RequiredAcker) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for RequiredAcker
impl PartialEq for RequiredAcker
Sourceimpl PartialOrd for RequiredAcker
impl PartialOrd for RequiredAcker
Sourceimpl Serialize for RequiredAcker
impl Serialize for RequiredAcker
impl StructuralPartialEq for RequiredAcker