Debug

Struct Debug 

#[non_exhaustive]
pub struct Debug { pub enable_debug_inspection: bool, }
Debug options for dataflow development and troubleshooting.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
enable_debug_inspection: bool

When true, daemons mirror every node output to the coordinator WebSocket so that dora topic echo, dora topic hz, and dora topic info can inspect runtime messages.