pub struct OperatorConfig {Show 16 fields
pub name: Option<String>,
pub description: Option<String>,
pub inputs: BTreeMap<DataId, Input>,
pub outputs: BTreeSet<DataId>,
pub output_types: BTreeMap<DataId, String>,
pub output_framing: BTreeMap<DataId, OutputFraming>,
pub input_types: BTreeMap<DataId, String>,
pub output_metadata: BTreeMap<DataId, Vec<String>>,
pub pattern: Option<String>,
pub source: OperatorSource,
pub build: Option<String>,
pub send_stdout_as: Option<String>,
pub send_logs_as: Option<String>,
pub min_log_level: Option<String>,
pub max_log_size: Option<String>,
pub max_rotated_files: Option<u32>,
}Fields
name: Option<String>Human-readable operator name
description: Option<String>Detailed description of the operator
inputs: BTreeMap<DataId, Input>Input data connections
outputs: BTreeSet<DataId>Output data identifiers
output_types: BTreeMap<DataId, String>Optional type annotations for outputs
output_framing: BTreeMap<DataId, OutputFraming>Per-output framing overrides (default: Raw for all).
input_types: BTreeMap<DataId, String>Optional type annotations for inputs
output_metadata: BTreeMap<DataId, Vec<String>>Required metadata keys per output
pattern: Option<String>Communication pattern shorthand (e.g. service-server)
source: OperatorSourceOperator source configuration (Python, shared library, etc.)
build: Option<String>Build commands for this operator
send_stdout_as: Option<String>Redirect stdout to data output
send_logs_as: Option<String>Redirect structured log entries to a data output as JSON strings
min_log_level: Option<String>Minimum log level for this operator
max_log_size: Option<String>Maximum log file size before rotation (e.g. “50MB”, “1GB”)
max_rotated_files: Option<u32>Maximum number of rotated log files to keep (default: 5)