Re-exports
pub use crate::common::DataMessage;pub use crate::common::Timestamped;
Structs
- Node
Config - Output
Routing - Data-plane routing for one node output — see
NodeConfig::output_routing. - Required
Acker - Identity of one consumer input that must ack a producer’s startup markers
before the producer may switch the corresponding output to the direct zenoh
path — see
OutputRouting::required_ackers. - Runtime
Config