pub enum NodeEvent {
Stop,
Reload {
operator_id: Option<OperatorId>,
},
Input {
id: DataId,
metadata: Metadata,
data: Option<DataMessage>,
},
InputClosed {
id: DataId,
},
AllInputsClosed,
NodeFailed {
affected_input_ids: Vec<DataId>,
error: String,
source_node_id: NodeId,
},
}Variants
Stop
Reload
Fields

operator_id: Option<OperatorId>Input
InputClosed
AllInputsClosed
Notifies a node that all its inputs have been closed.
This event is only sent to nodes that have at least one input.
NodeFailed