pub struct Metadata {
pub type_info: ArrowTypeInfo,
pub parameters: MetadataParameters,
/* private fields */
}Expand description
Additional data that is sent as part of output messages.
Includes a timestamp, type information, and additional user-provided parameters.
Fields
type_info: ArrowTypeInfoparameters: MetadataParametersImplementations
Sourceimpl Metadata
impl Metadata
pub fn new(timestamp: Timestamp, type_info: ArrowTypeInfo) -> Self
pub fn from_parameters( timestamp: Timestamp, type_info: ArrowTypeInfo, parameters: MetadataParameters, ) -> Self
pub fn timestamp(&self) -> Timestamp
Sourcepub fn get(&self, key: &str) -> Option<&Parameter>
pub fn get(&self, key: &str) -> Option<&Parameter>
Returns a raw metadata parameter by key.
This method only accesses user-provided metadata parameters.
It does not return fields such as the timestamp or type information.
For example, get("timestamp") is not equivalent to Metadata::timestamp.
Sourcepub fn get_or<'a, T>(&'a self, key: &str, default: T) -> T
pub fn get_or<'a, T>(&'a self, key: &str, default: T) -> T
Returns the parameter for key converted to T, or default if missing or wrong type.
pub fn open_telemetry_context(&self) -> String